==> pim-data-exporter-18.11.80.tar.xz: pim-data-exporter-18.11.80/core/addressbook/exportaddressbookjob.h <==
/*
   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef EXPORTADDRESSBOOKJOB_H
#define EXPORTADDRESSBOOKJOB_H

#include "abstractimportexportjob.h"
#include "pimsettingexportercore_private_export.h"
class ArchiveStorage;

class PIMSETTINGEXPORTER_TESTS_EXPORT ExportAddressbookJob : public AbstractImportExportJob
{
    Q_OBJECT
public:
    explicit ExportAddressbookJob(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
    ~ExportAddressbookJob() override;

    void start() override;

private:
    void slotCheckBackupConfig();
    void slotCheckBackupResource();
    void slotWriteNextArchiveResource();
    void slotAddressbookJobTerminated();

    void backupConfig();
    int mIndexIdentifier = 0;
};

#endif // EXPORTADDRESSBOOKJOB_H

==> pim-data-exporter-19.07.80.tar.xz: pim-data-exporter-19.07.80/core/addressbook/exportaddressbookjob.h <==
/*
   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef EXPORTADDRESSBOOKJOB_H
#define EXPORTADDRESSBOOKJOB_H

#include "abstractimportexportjob.h"
#include "pimdataexportercore_private_export.h"
class ArchiveStorage;

class PIMDATAEXPORTER_TESTS_EXPORT ExportAddressbookJob : public AbstractImportExportJob
{
    Q_OBJECT
public:
    explicit ExportAddressbookJob(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
    ~ExportAddressbookJob() override;

    void start() override;

private:
    void slotCheckBackupConfig();
    void slotCheckBackupResource();
    void slotWriteNextArchiveResource();
    void slotAddressbookJobTerminated();

    void backupConfig();
    int mIndexIdentifier = 0;
};

#endif // EXPORTADDRESSBOOKJOB_H
